==> camel-k-model-v1-6.2.0-sources.jar: io/fabric8/camelk/v1/CamelCatalogFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CamelCatalogFluentImpl<A extends CamelCatalogFluent<A>> extends BaseFluent<A> implements CamelCatalogFluent<A>{
  public CamelCatalogFluentImpl() {
  }
  public CamelCatalogFluentImpl(CamelCatalog instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private CamelCatalogSpecBuilder spec;
  private CamelCatalogStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public CamelCatalogFluent.MetadataNested<A> withNewMetadata() {
    return new CamelCatalogFluentImpl.MetadataNestedImpl();
  }
  public CamelCatalogFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new CamelCatalogFluentImpl.MetadataNestedImpl(item);
  }
  public CamelCatalogFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public CamelCatalogFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public CamelCatalogFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelCatalogSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public CamelCatalogSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(CamelCatalogSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new CamelCatalogSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public CamelCatalogFluent.SpecNested<A> withNewSpec() {
    return new CamelCatalogFluentImpl.SpecNestedImpl();
  }
  public CamelCatalogFluent.SpecNested<A> withNewSpecLike(CamelCatalogSpec item) {
    return new CamelCatalogFluentImpl.SpecNestedImpl(item);
  }
  public CamelCatalogFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public CamelCatalogFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new CamelCatalogSpecBuilder().build());
  }
  public CamelCatalogFluent.SpecNested<A> editOrNewSpecLike(CamelCatalogSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelCatalogStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CamelCatalogStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CamelCatalogStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CamelCatalogStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CamelCatalogFluent.StatusNested<A> withNewStatus() {
    return new CamelCatalogFluentImpl.StatusNestedImpl();
  }
  public CamelCatalogFluent.StatusNested<A> withNewStatusLike(CamelCatalogStatus item) {
    return new CamelCatalogFluentImpl.StatusNestedImpl(item);
  }
  public CamelCatalogFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CamelCatalogFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CamelCatalogStatusBuilder().build());
  }
  public CamelCatalogFluent.StatusNested<A> editOrNewStatusLike(CamelCatalogStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CamelCatalogFluentImpl that = (CamelCatalogFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CamelCatalogFluent.MetadataNested<N>> implements CamelCatalogFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) CamelCatalogFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends CamelCatalogSpecFluentImpl<CamelCatalogFluent.SpecNested<N>> implements CamelCatalogFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(CamelCatalogSpec item) {
      this.builder = new CamelCatalogSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new CamelCatalogSpecBuilder(this);
    }
    CamelCatalogSpecBuilder builder;
    public N and() {
      return (N) CamelCatalogFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CamelCatalogStatusFluentImpl<CamelCatalogFluent.StatusNested<N>> implements CamelCatalogFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CamelCatalogStatus item) {
      this.builder = new CamelCatalogStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CamelCatalogStatusBuilder(this);
    }
    CamelCatalogStatusBuilder builder;
    public N and() {
      return (N) CamelCatalogFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/CamelCatalogFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CamelCatalogFluentImpl<A extends CamelCatalogFluent<A>> extends BaseFluent<A> implements CamelCatalogFluent<A>{
  public CamelCatalogFluentImpl() {
  }
  public CamelCatalogFluentImpl(CamelCatalog instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private CamelCatalogSpecBuilder spec;
  private CamelCatalogStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public CamelCatalogFluentImpl.MetadataNested<A> withNewMetadata() {
    return new CamelCatalogFluentImpl.MetadataNestedImpl();
  }
  public CamelCatalogFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new CamelCatalogFluentImpl.MetadataNestedImpl(item);
  }
  public CamelCatalogFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public CamelCatalogFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public CamelCatalogFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelCatalogSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public CamelCatalogSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(CamelCatalogSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new CamelCatalogSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public CamelCatalogFluentImpl.SpecNested<A> withNewSpec() {
    return new CamelCatalogFluentImpl.SpecNestedImpl();
  }
  public CamelCatalogFluentImpl.SpecNested<A> withNewSpecLike(CamelCatalogSpec item) {
    return new CamelCatalogFluentImpl.SpecNestedImpl(item);
  }
  public CamelCatalogFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public CamelCatalogFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new CamelCatalogSpecBuilder().build());
  }
  public CamelCatalogFluentImpl.SpecNested<A> editOrNewSpecLike(CamelCatalogSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CamelCatalogStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CamelCatalogStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CamelCatalogStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CamelCatalogStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CamelCatalogFluentImpl.StatusNested<A> withNewStatus() {
    return new CamelCatalogFluentImpl.StatusNestedImpl();
  }
  public CamelCatalogFluentImpl.StatusNested<A> withNewStatusLike(CamelCatalogStatus item) {
    return new CamelCatalogFluentImpl.StatusNestedImpl(item);
  }
  public CamelCatalogFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CamelCatalogFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CamelCatalogStatusBuilder().build());
  }
  public CamelCatalogFluentImpl.StatusNested<A> editOrNewStatusLike(CamelCatalogStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CamelCatalogFluentImpl that = (CamelCatalogFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CamelCatalogFluentImpl.MetadataNested<N>> implements CamelCatalogFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) CamelCatalogFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends CamelCatalogSpecFluentImpl<CamelCatalogFluentImpl.SpecNested<N>> implements CamelCatalogFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(CamelCatalogSpec item) {
      this.builder = new CamelCatalogSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new CamelCatalogSpecBuilder(this);
    }
    CamelCatalogSpecBuilder builder;
    public N and() {
      return (N) CamelCatalogFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CamelCatalogStatusFluentImpl<CamelCatalogFluentImpl.StatusNested<N>> implements CamelCatalogFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CamelCatalogStatus item) {
      this.builder = new CamelCatalogStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CamelCatalogStatusBuilder(this);
    }
    CamelCatalogStatusBuilder builder;
    public N and() {
      return (N) CamelCatalogFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
